@@ -28,6 +28,7 @@ START_CHAR = 'start_char'
 END_CHAR = 'end_char'
 TYPE = 'type'
 SENTIMENT = 'sentiment'
+SRL = 'srl'
 
 def _readonly_setter(self, name):
     full_classname = self.__class__.__module__
@@ -145,8 +146,16 @@ class Document(StanzaObject):
         metasentences = metasentences if metasentences else [None] * len(sentences)
         for tokens, metadata in zip(sentences, metasentences):
             self.sentences.append(Sentence(tokens, doc=self, metadata=metadata))
-            begin_idx, end_idx = self.sentences[-1].tokens[0].start_char, self.sentences[-1].tokens[-1].end_char
-            if all([self.text is not None, begin_idx is not None, end_idx is not None]): self.sentences[-1].text = self.text[begin_idx: end_idx]
+            sentence_text = ''
+            if metadata:
+                split_metadata = metadata.split('\n')
+                for l in split_metadata:
+                    if len(l) > 9 and l[:9] == '# text = ':
+                        sentence_text = l[9:]
+                        self.sentences[-1].text = sentence_text
+            if not sentence_text:
+                begin_idx, end_idx = self.sentences[-1].tokens[0].start_char, self.sentences[-1].tokens[-1].end_char
+                if all([self.text is not None, begin_idx is not None, end_idx is not None]): self.sentences[-1].text = self.text[begin_idx: end_idx]
 
         self.num_tokens = sum([len(sentence.tokens) for sentence in self.sentences])
         self.num_words = sum([len(sentence.words) for sentence in self.sentences])
@@ -178,6 +187,10 @@ class Document(StanzaObject):
                 units = sentence.tokens
             else:
                 units = sentence.words
+            if 'srl' in fields:
+                for unit in units:
+                    misc = {uni.split('=')[0]: uni.split('=')[1] for uni in unit.misc.split('|')} if unit.misc is not None else None
+                    unit.srl = misc['SRL'] if misc is not None and 'SRL' in misc else None
             for unit in units:
                 if len(fields) == 1:
                     cursent += [getattr(unit, fields[0])]
@@ -548,9 +561,10 @@ class Token(StanzaObject):
         assert self._id and self._text, 'id and text should be included for the token'
         self._misc = token_entry.get(MISC, None)
         self._ner = token_entry.get(NER, None)
+        self._srl = token_entry.get(SRL, None)
         self._words = words if words is not None else []
-        self._start_char = None
-        self._end_char = None
+        self._start_char = token_entry.get(START_CHAR, None)
+        self._end_char = token_entry.get(END_CHAR, None)
 
         if self._misc is not None:
             self.init_from_misc()
@@ -631,10 +645,20 @@ class Token(StanzaObject):
         """ Set the token's NER tag. Example: 'B-ORG'"""
         self._ner = value if self._is_null(value) == False else None
 
+    @property
+    def srl(self):
+        """ Access the SRL tag of this token. Example: 'ACT'"""
+        return self._srl
+
+    @srl.setter
+    def srl(self, value):
+        """ Set the token's SRL tag. Example: 'ACT'"""
+        self._srl = value if self._is_null(value) == False else None
+
     def __repr__(self):
         return json.dumps(self.to_dict(), indent=2, ensure_ascii=False)
 
-    def to_dict(self, fields=[ID, TEXT, NER, MISC]):
+    def to_dict(self, fields=[ID, TEXT, NER, SRL, MISC]):
         """ Dumps the token into a list of dictionary for this token with its extended words
         if the token is a multi-word token.
         """
@@ -649,6 +673,8 @@ class Token(StanzaObject):
             word_dict = word.to_dict()
             if len(self.id) == 1 and NER in fields and getattr(self, NER) is not None: # propagate NER label to Word if it is a single-word token
                 word_dict[NER] = getattr(self, NER)
+            if len(self.id) == 1 and SRL in fields and getattr(self, SRL) is not None: # propagate SRL label to Word if it is a single-word token
+                word_dict[SRL] = getattr(self, SRL)
             ret.append(word_dict)
         return ret
 
@@ -682,6 +708,8 @@ class Word(StanzaObject):
         self._deprel = word_entry.get(DEPREL, None)
         self._deps = word_entry.get(DEPS, None)
         self._misc = word_entry.get(MISC, None)
+        self._start_char = word_entry.get(START_CHAR, None)
+        self._end_char = word_entry.get(END_CHAR, None)
         self._parent = None
 
         if self._misc is not None:
