@@ -1,8 +1,12 @@
 """
 Utils and wrappers for scoring parsers.
 """
+import logging
+
 from classla.models.common.utils import ud_scores
 
+logger = logging.getLogger('classla')
+
 def score(system_conllu_file, gold_conllu_file, verbose=True):
     """ Wrapper for UD parser scorer. """
     evaluation = ud_scores(gold_conllu_file, system_conllu_file)
@@ -12,7 +16,7 @@ def score(system_conllu_file, gold_conllu_file, verbose=True):
     f = el.f1
     if verbose:
         scores = [evaluation[k].f1 * 100 for k in ['LAS', 'MLAS', 'BLEX']]
-        print("LAS\tMLAS\tBLEX")
-        print("{:.2f}\t{:.2f}\t{:.2f}".format(*scores))
+        logger.info("LAS\tMLAS\tBLEX")
+        logger.info("{:.2f}\t{:.2f}\t{:.2f}".format(*scores))
     return p, r, f
 
