@@ -34,6 +34,9 @@ class Trainer(BaseTrainer):
         if model_file is not None:
             # load everything from file
             self.load(model_file, pretrain)
+
+            # ugly fix for <PAD> outputs
+            self.vocab._vocabs['deprel']._id2unit[0] = 'dep'
         else:
             assert all(var is not None for var in [args, vocab, pretrain])
             # build model from scratch
