@@ -8,6 +8,8 @@ from collections import Counter
 
 from classla.models.ner.utils import decode_from_bioes
 
+logger = logging.getLogger('classla')
+
 def score_by_entity(pred_tag_sequences, gold_tag_sequences, verbose=True):
     """ Score predicted tags at the entity level.
 
@@ -21,7 +23,7 @@ def score_by_entity(pred_tag_sequences, gold_tag_sequences, verbose=True):
     """
     assert(len(gold_tag_sequences) == len(pred_tag_sequences)), \
         "Number of predicted tag sequences does not match gold sequences."
-
+    
     def decode_all(tag_sequences):
         # decode from all sequences, each sequence with a unique id
         ents = []
@@ -56,6 +58,10 @@ def score_by_entity(pred_tag_sequences, gold_tag_sequences, verbose=True):
     if prec_micro + rec_micro > 0:
         f_micro = 2.0 * prec_micro * rec_micro / (prec_micro + rec_micro)
     
+    if verbose:
+        logger.info("Prec.\tRec.\tF1")
+        logger.info("{:.2f}\t{:.2f}\t{:.2f}".format( \
+            prec_micro*100, rec_micro*100, f_micro*100))
     return prec_micro, rec_micro, f_micro
 
 
@@ -103,6 +109,10 @@ def score_by_token(pred_tag_sequences, gold_tag_sequences, verbose=True):
     if prec_micro + rec_micro > 0:
         f_micro = 2.0 * prec_micro * rec_micro / (prec_micro + rec_micro)
     
+    if verbose:
+        logger.info("Prec.\tRec.\tF1")
+        logger.info("{:.2f}\t{:.2f}\t{:.2f}".format( \
+            prec_micro*100, rec_micro*100, f_micro*100))
     return prec_micro, rec_micro, f_micro
 
 def test():
