@@ -5,11 +5,12 @@ This tagger uses highway BiLSTM layers with character and word-level representat
 to produce consistant POS and UFeats predictions.
 For details please refer to paper: https://nlp.stanford.edu/pubs/qi2018universal.pdf.
 """
-
+import csv
 import sys
 import os
 import shutil
 import time
+from collections import Counter
 from datetime import datetime
 import argparse
 import numpy as np
@@ -26,7 +27,7 @@ from classla.models.common.doc import *
 from classla.utils.conll import CoNLL
 from classla.models import _training_logging
 
-def parse_args():
+def parse_args(args=None):
     parser = argparse.ArgumentParser()
     parser.add_argument('--data_dir', type=str, default='data/pos', help='Root dir for saving models.')
     parser.add_argument('--wordvec_dir', type=str, default='extern_data/word2vec', help='Directory of word vectors.')
@@ -36,7 +37,9 @@ def parse_args():
     parser.add_argument('--output_file', type=str, default=None, help='Output CoNLL-U file.')
     parser.add_argument('--gold_file', type=str, default=None, help='Output CoNLL-U file.')
     parser.add_argument('--pretrain_file', type=str, default=None, help='Input file containing pretrained data.')
-    parser.add_argument('--constrain_via_lexicon', type=str, default=None, help="Input location of lemmatization model.")
+    parser.add_argument('--use_lexicon', type=str, default=None, help="Input location of lemmatization model.")
+    parser.add_argument('--inflectional_lexicon_path', type=str, default=None, help="Input location of inflectional lexicon (i.e. sloleks).")
+    parser.add_argument('--lemma_pretag', action='store_true', help="Use pretag from tokenization processor.")
 
     parser.add_argument('--mode', default='train', choices=['train', 'predict'])
     parser.add_argument('--lang', type=str, help='Language')
@@ -81,13 +84,14 @@ def parse_args():
     parser.add_argument('--seed', type=int, default=1234)
     parser.add_argument('--cuda', type=bool, default=torch.cuda.is_available())
     parser.add_argument('--cpu', action='store_true', help='Ignore CUDA.')
-    args = parser.parse_args()
+    args = parser.parse_args(args=args)
     return args
 
-def main():
+
+def main(args=None):
     sys.setrecursionlimit(50000)
 
-    args = parse_args()
+    args = parse_args(args=args)
 
     torch.manual_seed(args.seed)
     np.random.seed(args.seed)
@@ -105,6 +109,62 @@ def main():
     else:
         evaluate(args)
 
+
+def generate_new_composite_dict(inflectional_lexicon_path, train_batch):
+    # generate initial composite dictionary from all train data
+    train_dict = train_batch.doc.get([TEXT, XPOS, UPOS, FEATS, LEMMA])
+    inflectional_dict = set()
+
+    lemmas_frequencies = {}
+    # get lemma frequencies
+    with open(inflectional_lexicon_path) as csvfile:
+        csv_reader = csv.reader(csvfile, delimiter='\t')
+        for row in csv_reader:
+            if row[0] == 'FORM' and row[1] == 'LEMMA':   # ignore header line
+                continue
+
+            # if row[6] is not float
+            if re.match(r'^-?\d+(?:\.\d+)$', row[6]) is None:
+                lemmas_frequencies[row[1]] = float(row[3]) if row[1] not in lemmas_frequencies else lemmas_frequencies[
+                                                                                                        row[1]] + float(
+                    row[3])
+                upos_ufeats = row[6].split()
+                ufeats = '|'.join(sorted(upos_ufeats[1:], key=lambda x: x.lower())) if upos_ufeats[1:] else '_'
+                inflectional_dict.add((row[0].lower(), row[2], upos_ufeats[0],
+                                       ufeats, float(row[3]), row[1]))
+
+            else:
+                lemmas_frequencies[row[1]] = float(row[6]) if row[1] not in lemmas_frequencies else lemmas_frequencies[row[1]] + float(row[6])
+                # '_' fix
+                ufeats = row[5] if row[5] else '_'
+                inflectional_dict.add((row[0].lower(), row[3], row[4], ufeats, float(row[6]), row[1]))
+
+    composite_dict = sorted(inflectional_dict, key=lambda x: x[4], reverse=True)
+    all_keys = {}
+
+    cleaned_composite_dict = []
+    i = 0
+    for el in composite_dict:
+        if (el[0], el[1], el[2], el[3]) not in all_keys:
+            all_keys[(el[0], el[1], el[2], el[3])] = (el, i)
+            cleaned_composite_dict.append((el[0], el[1], el[2], el[3], el[5]))
+            i += 1
+        else:
+            if el[5] in lemmas_frequencies and all_keys[(el[0], el[1], el[2], el[3])][0][5] in lemmas_frequencies and \
+                    lemmas_frequencies[all_keys[(el[0], el[1], el[2], el[3])][0][5]] < lemmas_frequencies[el[5]]:
+                old_el, updating_index = all_keys[(el[0], el[1], el[2], el[3])]
+                all_keys[(el[0], el[1], el[2], el[3])] = (el, updating_index)
+                cleaned_composite_dict[updating_index] = (el[0], el[1], el[2], el[3], el[5])
+
+    train_dict = [(el[0], el[1], el[2], el[3], el[4]) if el[3] is not None else (el[0], el[1], el[2], '_', el[4])
+                  for el in train_dict]
+    train_dict_most_common = Counter(train_dict).most_common()
+    filtered_train_dict = [el[0] for el in train_dict_most_common
+                           if (el[0][0], el[0][1], el[0][2], el[0][3]) not in all_keys]
+    cleaned_composite_dict.extend(filtered_train_dict)
+    return cleaned_composite_dict
+
+
 def train(args):
     utils.ensure_dir(args['save_dir'])
     model_file = args['save_dir'] + '/' + args['save_name'] if args['save_name'] is not None \
@@ -117,12 +177,17 @@ def train(args):
         else args['pretrain_file']
     pretrain = Pretrain(pretrain_file, vec_file, args['pretrain_max_vocab'])
 
+
     # load data
     print("Loading data with batch size {}...".format(args['batch_size']))
     doc, metasentences = CoNLL.conll2dict(input_file=args['train_file'])
     train_doc = Document(doc, metasentences=metasentences)
     train_batch = DataLoader(train_doc, args['batch_size'], args, pretrain, evaluation=False)
     vocab = train_batch.vocab
+
+    # create inflectional_lexicon
+    inflectional_lexicon = generate_new_composite_dict(args['inflectional_lexicon_path'], train_batch) if args['inflectional_lexicon_path'] else None
+
     doc, metasentences = CoNLL.conll2dict(input_file=args['eval_file'])
     dev_doc = Document(doc, metasentences=metasentences)
     dev_batch = DataLoader(dev_doc, args['batch_size'], args, pretrain, vocab=vocab, evaluation=True, sort_during_eval=True)
@@ -186,7 +251,7 @@ def train(args):
                 # save best model
                 if len(dev_score_history) == 0 or dev_score > max(dev_score_history):
                     last_best_step = global_step
-                    trainer.save(model_file)
+                    trainer.save(model_file, inflectional_lexicon=inflectional_lexicon)
                     print("new best model saved.")
                     best_dev_preds = dev_preds
 
