@@ -7,3 +7,5 @@ POS = 'pos'
 LEMMA = 'lemma'
 DEPPARSE = 'depparse'
 NER = 'ner'
+SRL = 'srl'
+SENTIMENT = 'sentiment'
